@@ -1,15 +1,15 @@
-# $Id: as3935.py 1551 2016-09-25 17:01:36Z mwall $
+# $Id: as3935.py 1560 2016-09-28 20:01:07Z mwall $
 # Copyright 2015 Matthew Wall
 
 """
 A service for weewx that reads the AS3935 lightning sensor range.  This service
 will add two fields to each archive record:
 
-  lightning_strikes - number of lightning strikes in the pass archive interval
+  lightning_strikes - number of lightning strikes in the past interval
   avg_distance - average distance of the lightning strikes
 
-To track these and use them in reports and plots, extend the schema as
-described in the weewx customization guide.
+To track these and use them in reports and plots, extend the weewx database
+schema as described in the weewx customization guide.
 
 The service can also save data to a separate 'lightning' database using the
 data_binding option.
@@ -35,16 +35,16 @@ the sensor.
 Packet binding:
 
 The service can be bound to LOOP packets or archive records.  Default is
-archive records.  Use the binding parameter to specify, for example:
+archive records.  Use the binding parameter to specify.  For example, to
+augment LOOP packets instead of the default, which is archive records:
 
 [AS3935]
     ...
     binding = loop
 
-Saving lightning data to a separate database:
+Data binding:
 
-By default, this extension saves data to the standard weewx database.  You
-can record every lightning strike by saving lightning data to a separate
+You can record every lightning strike by saving lightning data to a separate
 database.  To do this, then specify a data_binding for that database and the
 associated DataBinding and Database entries in the weewx configuration file:
 
@@ -80,7 +80,7 @@ from datetime import datetime
 from weewx.wxengine import StdService
 from weeutil.weeutil import to_bool
 
-VERSION = "0.5"
+VERSION = "0.6"
 
 if weewx.__version__ < "3.2":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -117,22 +117,30 @@ class AS3935(StdService):
         loginf("service version is %s" % VERSION)
         svc_dict = config_dict.get('AS3935', {})
         addr = int(svc_dict.get('address', 0x03))
+        loginf("address=0x%02x" % addr)
         bus = int(svc_dict.get('bus', 1))
+        loginf("bus=%s" % bus)
         indoors = to_bool(svc_dict.get('indoors', True))
+        loginf("indoors=%s" % indoors)
         noise_floor = int(svc_dict.get('noise_floor', 0))
+        loginf("noise_floor=%s" % noise_floor)
         calib = int(svc_dict.get('calibration', 0x6))
+        loginf("calibration=0x%02x" % calib)
         self.pin = int(svc_dict.get('pin', 17))
-        self.binding = svc_dict.get('data_binding', None)
+        loginf("pin=%s" % self.pin)
+        self.data_binding = svc_dict.get('data_binding', None)
+        loginf("data_binding=%s" % self.data_binding)
         pkt_binding = svc_dict.get('binding', 'archive')
+        loginf("binding=%s" % pkt_binding)
 
         self.data = []
 
         # if a binding was specified, then use it to save strikes to database
-        if self.binding is not None:
+        if self.data_binding is not None:
             # configure the lightning database
             dbm_dict = weewx.manager.get_manager_dict(
                 config_dict['DataBindings'], config_dict['Databases'],
-                self.binding, default_binding_dict=get_default_binding_dict())
+                self.data_binding, default_binding_dict=get_default_binding_dict())
             with weewx.manager.open_manager(dbm_dict, initialize=True) as dbm:
                 # ensure schema on disk matches schema in memory
                 dbcol = dbm.connection.columnsOf(dbm.table_name)
@@ -195,14 +203,14 @@ class AS3935(StdService):
         self.data = []
 
     def save_data(self, strike_ts, distance):
-        if self.binding is None:
+        if self.data_binding is None:
             return
         rec = {'dateTime': strike_ts,
                'usUnits': weewx.METRIC,
                'distance': distance}
         dbm_dict = weewx.manager.get_manager_dict(
             self.config_dict['DataBindings'], self.config_dict['Databases'],
-            self.binding, default_binding_dict=get_default_binding_dict())
+            self.data_binding, default_binding_dict=get_default_binding_dict())
         with weewx.manager.open_manager(dbm_dict) as dbm:
             dbm.addRecord(rec)
 
